aboutsummaryrefslogtreecommitdiff
path: root/tests/functional_tests/functional_tests_rpc.py
diff options
context:
space:
mode:
authorj-berman <justinberman@protonmail.com>2022-08-15 19:50:34 -0700
committerj-berman <justinberman@protonmail.com>2022-09-06 17:20:23 -0600
commitb03d7091f7a0c2bd78f28ccb27a6481bb409d4dd (patch)
treedefa75066d02f7b535e826ad88aebb9769bd9195 /tests/functional_tests/functional_tests_rpc.py
parentwallet2: do not assume imported outputs must be non empty (diff)
downloadmonero-b03d7091f7a0c2bd78f28ccb27a6481bb409d4dd.tar.xz
wallet2: fixes for export/import output flow
- only allow offline wallets to import outputs - don't import empty outputs - export subaddress indexes when exporting outputs
Diffstat (limited to '')
-rwxr-xr-xtests/functional_tests/functional_tests_rpc.py6
1 files changed, 4 insertions, 2 deletions
diff --git a/tests/functional_tests/functional_tests_rpc.py b/tests/functional_tests/functional_tests_rpc.py
index eb8d51f08..d020bf2f6 100755
--- a/tests/functional_tests/functional_tests_rpc.py
+++ b/tests/functional_tests/functional_tests_rpc.py
@@ -40,8 +40,9 @@ except:
N_MONERODS = 4
# 4 wallets connected to the main offline monerod
-# a wallet connected to the first local online monerod
-N_WALLETS = 5
+# 1 wallet connected to the first local online monerod
+# 1 offline wallet
+N_WALLETS = 6
WALLET_DIRECTORY = builddir + "/functional-tests-directory"
FUNCTIONAL_TESTS_DIRECTORY = builddir + "/tests/functional_tests"
@@ -61,6 +62,7 @@ wallet_extra = [
["--daemon-port", "18180"],
["--daemon-port", "18180"],
["--daemon-port", "18182"],
+ ["--offline"],
]
command_lines = []